package com.jg.util;


import com.alibaba.fastjson2.JSON;
import com.serotonin.modbus4j.ModbusFactory;
import com.serotonin.modbus4j.ModbusMaster;
import com.serotonin.modbus4j.ip.IpParameters;
import lombok.extern.slf4j.Slf4j;

/**
 * <p>
 *     modbus读取工具类
 * </p>
 *
 * @author lxp
 * @version V1.0
 * @since 2023/1/1  22:31
 */
@Slf4j
public class ModBusUtil {

    public static ModbusFactory modbusFactory;

    static {
        modbusFactory = new ModbusFactory();
    }

    /**
     * 获取 Modbus Master
     *
     * @return ModBusMaster
     */
    public static ModbusMaster createMaster(String host, Integer port) {
        try {
            IpParameters params = new IpParameters();
            params.setHost(host);
            params.setPort(port);
            //这个属性确定了协议帧是否是通过tcp封装的RTU结构，采用modbus tcp/ip时，要设为false,
            // 采用modBus rtu over tcp/ip时，要设为true
            params.setEncapsulated(false);
            ModbusMaster master = modbusFactory.createTcpMaster(params, false);
            master.setTimeout(4000);
            master.setRetries(3);
            return master;
        } catch (Exception e) {
            log.error("连接失败, Modbus Tcp Connection Info ModbusSlaveInfo: {}", JSON.toJSONString("collectModuleInfo"));
            throw new RuntimeException(e);
        }
    }
}
